DeserializationClassNameNotFoundException class
Exception thrown when no deserialization handler exists for a class name.
This extends FormatException to preserve compatibility with callers that treated an unknown class name as malformed serialized data.
- Inheritance
-
- Object
- FormatException
- DeserializationClassNameNotFoundException
Constructors
- DeserializationClassNameNotFoundException({required Object? className})
- Creates a new DeserializationClassNameNotFoundException.
Properties
- className → Object?
-
The class name for which no deserialization handler was found.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A message describing the format error.
finalinherited
- offset → int?
-
The offset in source where the error was detected.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → dynamic
-
The actual source input which caused the error.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a description of the format exception.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited