EmailCreateAccountRequest class abstract

A request for creating an email signin. Created during the sign up process to keep track of the user's details and verification code.

Implemented types

Constructors

EmailCreateAccountRequest({int? id, required String userName, required String email, required String hash, required String verificationCode})
factory
EmailCreateAccountRequest.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

email ↔ String
The email of the user.
getter/setter pair
hash ↔ String
Hash of the user's requested password.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The database id, set if the object has been inserted into the database or if it has been fetched from the database. Otherwise, the id will be null.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName ↔ String
The name of the user.
getter/setter pair
verificationCode ↔ String
The verification code sent to the user.
getter/setter pair

Methods

copyWith({int? id, String? userName, String? email, String? hash, String? verificationCode}) → EmailCreateAccountRequest
Returns a shallow copy of this EmailCreateAccountRequest with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited