EndpointStatus class Endpoint

Endpoint for getting status for a signed in user and module configuration.

Inheritance

Constructors

EndpointStatus(EndpointCaller caller)

Properties

caller → EndpointCaller
Holds a reference to the caller class.
finalinherited
client ↔ ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUserInfo() → Future<UserInfo?>
Gets the UserInfo for a signed in user, or null if the user is currently not signed in with the server.
getUserSettingsConfig() → Future<UserSettingsConfig>
Gets the server configuration.
isSignedIn() → Future<bool>
Returns true if the client user is signed in.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signOutAllDevices() → Future<void>
Signs out a user from all active devices.
signOutDevice() → Future<void>
Signs out a user from the current device.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited