GeographyGeometryCollection class

Represents a PostGIS GeometryCollection — a heterogeneous collection of Geography values (points, line strings, polygons).

Implemented types
Available extensions

Constructors

GeographyGeometryCollection({required List<Geography> geometries, int srid = Geography.defaultSrid})
Creates a new GeographyGeometryCollection.
const
GeographyGeometryCollection.fromBinary(Uint8List bytes)
Creates a GeographyGeometryCollection from its EWKB binary representation as returned by PostgreSQL for geography columns.
factory

Properties

geometries List<Geography>
The geometries in this collection.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srid int
Spatial reference system identifier. Defaults to WGS 84 (EPSG:4326).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEwkt() String
Returns the EWKT representation for PostGIS, e.g. SRID=4326;POINT(-0.12 51.5).
override
toJson() String

Available on GeographyGeometryCollection, provided by the GeographyGeometryCollectionJsonExtension extension

Returns the EWKT representation as a String.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override