MethodStreamMessage class

A message sent to a method stream.

Inheritance
Implemented types

Constructors

MethodStreamMessage(Map data, SerializationManager _serializationManager)
Creates a new MethodStreamMessage. The object must be an object processed by the SerializationManager.wrapWithClassName method.

Properties

connectionId → UuidValue
The connection id that uniquely identifies the stream.
final
endpoint → String
The endpoint the message is sent to.
final
hashCode → int
The hash code for this object.
no setterinherited
method → String
The method the message is sent to.
final
object → dynamic
The object that was sent.
final
parameter → String?
The parameter the message is sent to. If this is null the message is sent to the return stream of the method.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildMessage({required String endpoint, required String method, required UuidValue connectionId, String? parameter, required dynamic object, required SerializationManager serializationManager}) → String
Builds a MethodStreamMessage message.