OpenMethodStreamException class

Thrown if opening a method stream fails.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message to show to the user.
finalinherited
responseType OpenMethodStreamResponseType
The response type that caused the exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited