ServerpodClientMultipleEndpointsFound class final

Thrown if the client tries to call an endpoint by type, but multiple endpoints of that type exists. The user should disambiguate by using the name parameter.

Inheritance

Constructors

ServerpodClientMultipleEndpointsFound(Type type, Iterable<EndpointRef> endpoints)
Creates an Multiple Endpoints Found Exception.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message to show to the user.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited