WebSocketConnectException class

Thrown if the WebSocket connection fails.

Inheritance

Constructors

WebSocketConnectException(Object? error, [StackTrace? stackTrace])
Creates a new WebSocketConnectException.
const

Properties

error Object?
The error that caused the exception.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message to show to the user.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace of the error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited